@@ -19,19 +19,12 @@ class SickwResults:
     status: str = "failed"
 
     def __init__(self, serial_number: str, service: int = APPLE_SERIAL_INFO) -> None:
-        """Instantiate result with data from API from passed serial number and service.
-        Set status to false if sickw says not success or no HTML result string"""
+        """Instantiate result with data from API from passed serial number and service.  Set status to false if sickw
+        says not success or no HTML result string"""
 
-        current_params = {
-            "imei": serial_number,
-            "service": service,
-            "key": config.SICKW_API_KEY,
-            "format": "JSON",
-        }
+        current_params = {"imei": serial_number, "service": service, "key": config.SICKW_API_KEY, "format": "JSON"}
         headers = {"User-Agent": "My User Agent 1.0"}
-        response = requests.get(
-            "https://sickw.com/api.php", params=current_params, headers=headers, timeout=60
-        )
+        response = requests.get("https://sickw.com/api.php", params=current_params, headers=headers, timeout=60)
         response_json = response.json()
 
         self.serial_number = serial_number
