@@ -86,7 +86,8 @@ class ChatGPTCog(commands.Cog):
                 max_tokens=1000,
                 n=1,
                 stop=None,
-                temperature=0.75,
+                temperature=0,
+                top_p=1,
                 api_key=config.OPENAI_API_KEY,
             )
         except openai.error.InvalidRequestError as exception:
